@@ -8,14 +8,14 @@ use Log::Any '$log';
 
 use Data::Clone;
 #use List::MoreUtils qw(firstidx);
-use SHARYANTO::Complete::Util qw(
+use Complete::Util qw(
                                     complete_array
                                     complete_env
                                     complete_file
                                     parse_shell_cmdline
                             );
 
-our $VERSION = '0.43'; # VERSION
+our $VERSION = '0.44'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -285,7 +285,7 @@ sub complete_arg_val {
 
             $log->tracef("arg spec's completion is not a coderef");
             if ($args{riap_client} && $args{riap_server_url}) {
-                $log->tracef("trying to do complete_arg_val from the server");
+                $log->tracef("trying to request complete_arg_val to server");
                 my $res = $args{riap_client}->request(
                     complete_arg_val => $args{riap_server_url},
                     {(uri=>$args{riap_uri}) x !!defined($args{riap_uri}),
@@ -319,7 +319,16 @@ sub complete_arg_val {
         $log->tracef("no completion from metadata possible, declining");
         return undef;
     }
+
     complete_array(array=>$words, word=>$word, ci=>$ci);
+
+    # when bash supports autocorrect (or "programmable dirspell" perhaps), we
+    # can return $words directly. suppose arg val is [audry, audrey, adrian,
+    # andy]. if word is 'au' then completion is simply [audry, audrey]. but if
+    # user mistypes and word is 'adu', we can still suggest [audry, audrey] and
+    # future bash can replace buffer with 'aud'. currently it replaces buffer
+    # with 'a' and won't display any completion.
+
 }
 
 my $m = clone($SPEC{complete_arg_val});
@@ -374,7 +383,7 @@ sub complete_arg_elem {
 
             $log->tracef("arg spec's element_completion is not a coderef");
             if ($args{riap_client} && $args{riap_server_url}) {
-                $log->tracef("trying to do complete_arg_elem from the server");
+                $log->tracef("trying to request complete_arg_elem to server");
                 my $res = $args{riap_client}->request(
                     complete_arg_elem => $args{riap_server_url},
                     {(uri=>$args{riap_uri}) x !!defined($args{riap_uri}),
@@ -937,7 +946,7 @@ Perinci::Sub::Complete - Shell completion routines using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.43 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2014-06-19.
+This document describes version 0.44 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2014-06-25.
 
 =head1 SYNOPSIS
 
